==> nextcloud-app-news-15.4.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/it.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Richiesta non riuscita, connessione di rete non disponibile!",
    "Request unauthorized. Are you logged in?" : "Richiesta non autorizzata. Hai effettuato l'accesso?",
    "Request forbidden. Are you an admin?" : "Richiesta vietata. Sei un amministratore?",
    "Token expired or app not enabled! Reload the page!" : "Token scaduto o applicazione non abilitata! Ricarica la pagina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Errore interno del server! Controlla il file data/nextcloud.log per informazioni aggiuntive.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Richiesta non riuscita, Nextcloud è attualmente in manutenzione!",
    "News folders" : "Cartelle notizie",
    "News" : "Notizie",
    "An RSS/Atom feed reader" : "Un lettore di fonti RSS/Atom",
    "The News app is an RSS/Atom feed reader for Nextcloud which can be synced with many mobile devices. A list of all clients and requirements can be found [in the README](https://github.com/nextcloud/news)\n\nBefore you update to a new version, [check the changelog](https://github.com/nextcloud/news/blob/master/CHANGELOG.md) to avoid surprises.\n\n**Important**: To enable feed updates you will need to enable either [Nextcloud system cron](https://docs.nextcloud.org/server/latest/admin_manual/configuration_server/background_jobs_configuration.html#cron) or use [an updater](https://github.com/nextcloud/news-updater) which uses the built in update API and disable cron updates. More information can be found [in the README](https://github.com/nextcloud/news)." : "L'applicazione Notizie è un lettore di fonti RSS/Atom per Nextcloud che può essere sincronizzato con molti dispositivi mobili. Un elenco di tutti i client e dei requisiti è disponibile [nel README](https://github.com/nextcloud/news)\n\nPrima di aggiornare a una nuova versione, [controlla le novità](https://github.com/nextcloud/news/blob/master/CHANGELOG.md) per evitare sorprese.\n\n**Importante**: per abilitare l'aggiornamento delle fonti dovrai attivare il [cron di sistema di Nextcloud](https://docs.nextcloud.org/server/latest/admin_manual/configuration_server/background_jobs_configuration.html#cron) o usare [uno strumento di aggiornamento](https://github.com/nextcloud/news-updater) che utilizza le API di aggiornamento integrate e disattivare gli aggiornamenti tramite cron. Altre informazioni sono disponibili [nel README](https://github.com/nextcloud/news).",
    "Use system cron for updates" : "Usa cron di sistema per gli aggiornamenti",
    "Disable this if you run a custom updater such as the Python updater included in the app." : "Disabilita questa opzione se esegui uno strumento di aggiornamento personalizzato come quello Python incluso nell'applicazione.",
    "Purge interval" : "Intervallo di cancellazione",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Numero minimo di secondi dopo i quali le fonti e le cartelle eliminate sono rimosse dal database; valori inferiori a 60 secondi sono ignorati.",
    "Maximum read count per feed" : "Numero massimo di letture per fonte",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definisce la quantità massima di articoli che possono essere letti per ogni fonte che non saranno eliminati dall'operazione di pulizia; se vecchi articoli riappaiono dopo essere stati letti, incrementa questo valore; valori negativi come -1 disattiveranno questa funzionalità.",
    "Maximum redirects" : "Numero massimo di redirezioni",
    "How many redirects the feed fetcher should follow." : "Quante redirezioni può seguire lo strumento di recupero delle fonti.",
    "Feed fetcher timeout" : "Ritardo massimo di attesa per il recupero della fonte",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Numero massimo di secondi di attesa per il caricamento di una fonte RSS o Atom; se richiede troppo tempo l'aggiornamento sarà interrotto.",
    "Explore Service URL" : "URL del servizio Esplora",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Se specificato, questo URL del servizio sarà interrogato per visualizzare le fonti nella sezione di esplorazione. Per tornare al servizio di esplorazione integrato, lascia vuoto questo campo.",
    "For more information check the wiki." : "Per ulteriori informazioni, consulta il wiki.",
    "Update interval" : "Intervallo di aggiornamento",
    "Interval in seconds in which the feeds will be updated." : "Intervallo in secondi nel quale le fonti saranno aggiornate.",
    "Saved" : "Salvato",
    "Download" : "Scarica",
    "Close" : "Chiudi",
    "Subscribe to" : "Sottoscrivi",
    "No articles available" : "Nessun articolo disponibile",
    "No unread articles available" : "Non sono disponibili articoli non letti",
    "Open website" : "Apri sito web",
    "Star article" : "Aggiungi ai preferiti",
    "Unstar article" : "Rimuovi dai preferiti",
    "Keep article unread" : "Mantieni l'articolo come non letto",
    "Remove keep article unread" : "Rimuovi il mantenimento dell'articolo come non letto",
    "by" : "da",
    "from" : "da",
    "Play audio" : "Riproduci audio",
    "Download audio" : "Scarica audio",
    "Download video" : "Scarica video",
    "Keyboard shortcut" : "Scorciatoia da tastiera",
    "Description" : "Descrizione",
    "right" : "destra",
    "Jump to next article" : "Salta all'articolo successivo",
    "left" : "sinistra",
    "Jump to previous article" : "Salta all'articolo precedente",
    "Toggle star article" : "Commuta l'aggiunta ai preferiti di un articolo",
    "Star article and jump to next one" : "Aggiungi l'articolo ai preferiti e salta al successivo",
    "Toggle keep current article unread" : "Commuta il mantenimento dell'articolo come non letto",
    "Open article in new tab" : "Apri articolo in una nuova scheda",
    "Toggle expand article in compact view" : "Commuta l'espansione dell'articolo nella vista compatta",
    "Refresh" : "Aggiorna",
    "Load next feed" : "Carica la fonte successiva",
    "Load previous feed" : "Carica la fonte precedente",
    "Load next folder" : "Carica la cartella successiva",
    "Load previous folder" : "Carica la cartella precedente",
    "Scroll to active navigation entry" : "Scorri per attivare la voce di navigazione",
    "Focus search field" : "Evidenzia il campo di ricerca",
    "Mark current article's feed/folder read" : "Marca la cartella/fonte dell'articolo attuale come letta",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Rilevata modalità cron Ajax o webcron! Le tue fonti non saranno aggiornate!",
    "How to set up the operating system cron" : "Come configurare cron del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installa e configura uno strumento di aggiornamento parallelo più veloce che utilizza le API di aggiornamento dell'applicazione News",
    "Subscribe" : "Sottoscrivi",
    "Web address" : "Indirizzo web",
    "Feed exists already!" : "La fonte esiste già!",
    "Folder" : "Cartella",
    "No folder" : "Nessuna cartella",
    "New folder" : "Nuova cartella",
    "Folder name" : "Nome della cartella",
    "Go back" : "Indietro",
    "Folder exists already!" : "La cartella esiste già!",
    "Credentials" : "Credenziali",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Le credenziali HTTP Basic Auth devono essere memorizzate senza cifratura! Chiunque abbia accesso al server o al database sarà in grado di accedervi!",
    "Username" : "Nome utente",
    "Password" : "Password",
    "Autodiscover Feed" : "Scoperta automatica fonte",
    "New Folder" : "Nuova cartella",
    "Create" : "Crea",
    "Explore" : "Esplora",
    "Update failed more than 50 times" : "L'aggiornamento non è riuscito più di 50 volte",
    "Deleted feed" : "Elimina la fonte",
    "Undo delete feed" : "Annulla l'eliminazione della fonte",
    "Rename" : "Rinomina",
    "Menu" : "Menu",
    "Mark read" : "Marca letti",
    "Unpin from top" : "Rimuovi dalla cima",
    "Pin to top" : "Appunta in cima",
    "Newest first" : "Prima i più recenti",
    "Oldest first" : "Prima i più datati",
    "Default order" : "Ordine predefinito",
    "Enable full text" : "Abilita intero testo",
    "Disable full text" : "Disabilita intero testo",
    "Unread updated" : "Non letti aggiornati",
    "Ignore updated" : "Ignora aggiornati",
    "Open feed URL" : "Apri URL della fonte",
    "Delete" : "Elimina",
    "Dismiss" : "Annulla",
    "Collapse" : "Contrai",
    "Deleted folder" : "Elimina la cartella",
    "Undo delete folder" : "Annulla l'eliminazione della cartella",
    "Starred" : "Preferiti",
    "Unread articles" : "Articoli non letti",
    "All articles" : "Tutti gli articoli",
    "Settings" : "Impostazioni",
    "Disable mark read through scrolling" : "Disabilita la marcatura come letto durante lo scorrimento",
    "Compact view" : "Visualizzazione compatta",
    "Expand articles on key navigation" : "Espandi gli articoli durante la navigazione con i tasti",
    "Show all articles" : "Mostra tutti gli articoli",
    "Reverse ordering (oldest on top)" : "Ordine inverso (più vecchio in alto)",
    "Subscriptions (OPML)" : "Sottoscrizioni (OPML)",
    "Import" : "Importa",
    "Export" : "Esporta",
    "Error when importing: File does not contain valid OPML" : "Errore di importazione: il file non contiene un OPML valido",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Errore durante l'importazione: il file OPML non contiene fonti né cartelle",
    "Unread/Starred Articles" : "Articoli non letti/preferiti",
    "Error when importing: file does not contain valid JSON" : "Errore durante l'importazione: il file non contiene JSON valido",
    "Help" : "Aiuto",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Documentation" : "Documentazione",
    "Report a bug" : "Segnala un bug"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-16.2.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/it.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Richiesta non riuscita, connessione di rete non disponibile!",
    "Request unauthorized. Are you logged in?" : "Richiesta non autorizzata. Hai effettuato l'accesso?",
    "Request forbidden. Are you an admin?" : "Richiesta vietata. Sei un amministratore?",
    "Token expired or app not enabled! Reload the page!" : "Token scaduto o applicazione non abilitata! Ricarica la pagina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Errore interno del server! Controlla il file data/nextcloud.log per informazioni aggiuntive.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Richiesta non riuscita, Nextcloud è attualmente in manutenzione!",
    "News feeds" : "Fonti di notizie",
    "Unread articles" : "Articoli non letti",
    "News" : "Notizie",
    "News folders" : "Cartelle delle notizie",
    "Shared with me" : "Condivisi con me",
    "An RSS/Atom feed reader" : "Un lettore di fonti RSS/Atom",
    "Use system cron for updates" : "Usa cron di sistema per gli aggiornamenti",
    "Disable this if you use a custom updater." : "Disabilita questa opzione se esegui uno strumento di aggiornamento personalizzato.",
    "Purge interval" : "Intervallo di cancellazione",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Numero minimo di secondi dopo i quali le fonti e le cartelle eliminate sono rimosse dal database; valori inferiori a 60 secondi sono ignorati.",
    "Maximum read count per feed" : "Numero massimo di letture per fonte",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definisce la quantità massima di articoli che possono essere letti per ogni fonte che non saranno eliminati dall'operazione di pulizia; se vecchi articoli riappaiono dopo essere stati letti, incrementa questo valore; valori negativi come -1 disattiveranno questa funzionalità.",
    "Maximum redirects" : "Numero massimo di redirezioni",
    "How many redirects the feed fetcher should follow." : "Quante redirezioni può seguire lo strumento di recupero delle fonti.",
    "Feed fetcher timeout" : "Ritardo massimo di attesa per il recupero della fonte",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Numero massimo di secondi di attesa per il caricamento di una fonte RSS o Atom; se richiede troppo tempo l'aggiornamento sarà interrotto.",
    "Explore Service URL" : "URL del servizio Esplora",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Se specificato, questo URL del servizio sarà interrogato per visualizzare le fonti nella sezione di esplorazione. Per tornare al servizio di esplorazione integrato, lascia vuoto questo campo.",
    "For more information check the wiki." : "Per ulteriori informazioni, consulta il wiki.",
    "Update interval" : "Intervallo di aggiornamento",
    "Interval in seconds in which the feeds will be updated." : "Intervallo in secondi nel quale le fonti saranno aggiornate.",
    "For more information check the documentation." : "Per ulteriori informazioni, consulta la documentazione.",
    "Saved" : "Salvato",
    "Download" : "Scarica",
    "Close" : "Chiudi",
    "Subscribe to" : "Sottoscrivi",
    "No articles available" : "Nessun articolo disponibile",
    "No unread articles available" : "Non sono disponibili articoli non letti",
    "Open website" : "Apri sito web",
    "Star article" : "Aggiungi ai preferiti",
    "Unstar article" : "Rimuovi dai preferiti",
    "Keep article unread" : "Mantieni l'articolo come non letto",
    "Remove keep article unread" : "Rimuovi il mantenimento dell'articolo come non letto",
    "Share" : "Condividi",
    "Share with users" : "Condividi con utenti",
    "Username" : "Nome utente",
    "No users found" : "Nessun utente trovato",
    "Error while searching for users" : "Errore nella ricerca di utenti",
    "Share on social media" : "Condividi nei social",
    "I wanted you to see this article" : "Vorrei che leggessi questo articolo",
    "Check out this article" : "Dai un'occhiata a questo articolo",
    "by" : "da",
    "from" : "da",
    "shared by" : "condiviso da",
    "Play audio" : "Riproduci audio",
    "Download audio" : "Scarica audio",
    "Download video" : "Scarica video",
    "Keyboard shortcut" : "Scorciatoia da tastiera",
    "Description" : "Descrizione",
    "right" : "destra",
    "Jump to next article" : "Salta all'articolo successivo",
    "left" : "sinistra",
    "Jump to previous article" : "Salta all'articolo precedente",
    "Toggle star article" : "Commuta l'aggiunta ai preferiti di un articolo",
    "Star article and jump to next one" : "Aggiungi l'articolo ai preferiti e salta al successivo",
    "Toggle keep current article unread" : "Commuta il mantenimento dell'articolo come non letto",
    "Open article in new tab" : "Apri articolo in una nuova scheda",
    "Toggle expand article in compact view" : "Commuta l'espansione dell'articolo nella vista compatta",
    "Refresh" : "Aggiorna",
    "Load next feed" : "Carica la fonte successiva",
    "Load previous feed" : "Carica la fonte precedente",
    "Load next folder" : "Carica la cartella successiva",
    "Load previous folder" : "Carica la cartella precedente",
    "Scroll to active navigation entry" : "Scorri per attivare la voce di navigazione",
    "Focus search field" : "Evidenzia il campo di ricerca",
    "Mark current article's feed/folder read" : "Marca la cartella/fonte dell'articolo attuale come letta",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Rilevata modalità cron Ajax o webcron! Le tue fonti non saranno aggiornate!",
    "How to set up the operating system cron" : "Come configurare cron del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installa e configura uno strumento di aggiornamento parallelo più veloce che utilizza le API di aggiornamento dell'applicazione News",
    "Subscribe" : "Sottoscrivi",
    "Web address" : "Indirizzo web",
    "Feed exists already!" : "La fonte esiste già!",
    "Folder" : "Cartella",
    "No folder" : "Nessuna cartella",
    "New folder" : "Nuova cartella",
    "Folder name" : "Nome della cartella",
    "Go back" : "Indietro",
    "Folder exists already!" : "La cartella esiste già!",
    "Credentials" : "Credenziali",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Le credenziali HTTP Basic Auth devono essere memorizzate senza cifratura! Chiunque abbia accesso al server o al database sarà in grado di accedervi!",
    "Password" : "Password",
    "Auto discover Feed" : "Scoperta automatica fonte",
    "New Folder" : "Nuova cartella",
    "Create" : "Crea",
    "Explore" : "Esplora",
    "Update failed more than 50 times" : "L'aggiornamento non è riuscito più di 50 volte",
    "Deleted feed" : "Elimina la fonte",
    "Undo delete feed" : "Annulla l'eliminazione della fonte",
    "Rename" : "Rinomina",
    "Menu" : "Menu",
    "Mark read" : "Marca letti",
    "Unpin from top" : "Rimuovi dalla cima",
    "Pin to top" : "Appunta in cima",
    "Newest first" : "Prima i più recenti",
    "Oldest first" : "Prima i più datati",
    "Default order" : "Ordine predefinito",
    "Enable full text" : "Abilita intero testo",
    "Disable full text" : "Disabilita intero testo",
    "Unread updated" : "Non letti aggiornati",
    "Ignore updated" : "Ignora aggiornati",
    "Open feed URL" : "Apri URL della fonte",
    "Delete" : "Elimina",
    "Dismiss" : "Annulla",
    "Collapse" : "Contrai",
    "Deleted folder" : "Elimina la cartella",
    "Undo delete folder" : "Annulla l'eliminazione della cartella",
    "Starred" : "Preferiti",
    "All articles" : "Tutti gli articoli",
    "Settings" : "Impostazioni",
    "Disable mark read through scrolling" : "Disabilita la marcatura come letto durante lo scorrimento",
    "Compact view" : "Visualizzazione compatta",
    "Expand articles on key navigation" : "Espandi gli articoli durante la navigazione con i tasti",
    "Show all articles" : "Mostra tutti gli articoli",
    "Reverse ordering (oldest on top)" : "Ordine inverso (più vecchio in alto)",
    "Subscriptions (OPML)" : "Sottoscrizioni (OPML)",
    "Import" : "Importa",
    "Export" : "Esporta",
    "Error when importing: File does not contain valid OPML" : "Errore di importazione: il file non contiene un OPML valido",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Errore durante l'importazione: il file OPML non contiene fonti né cartelle",
    "Unread/Starred Articles" : "Articoli non letti/preferiti",
    "Error when importing: file does not contain valid JSON" : "Errore durante l'importazione: il file non contiene JSON valido",
    "Help" : "Aiuto",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Documentation" : "Documentazione",
    "Report a bug" : "Segnala un bug"
},
"nplurals=2; plural=(n != 1);");
